@@ -1,30 +1,24 @@
+import cloudfiles
 import mimetypes
+from cloudfiles.errors import NoSuchObject, ResponseError
 
 from django.conf import settings
-from django.core.exceptions import ImproperlyConfigured
 from django.core.files import File
 from django.core.files.storage import Storage
-from django.utils.text import get_valid_filename
-
-try:
-    import cloudfiles
-    from cloudfiles.errors import NoSuchObject, ResponseError
-except ImportError:
-    raise ImproperlyConfigured("Could not load cloudfiles dependency. See "
-                               "http://www.mosso.com/cloudfiles.jsp.")
 
 USERNAME = getattr(settings, 'CUMULUS_USERNAME')
 API_KEY = getattr(settings, 'CUMULUS_API_KEY')
 CONTAINER = getattr(settings, 'CUMULUS_CONTAINER')
 TIMEOUT = getattr(settings, 'CUMULUS_TIMEOUT', 5)
 USE_SERVICENET = getattr(settings, 'CUMULUS_USE_SERVICENET', False)
+CNAMES = getattr(settings, 'CUMULUS_CNAMES', None)
 # TODO: implement TTL into cloudfiles methods
 TTL = getattr(settings, 'CUMULUS_TTL', 600)
 
 
 class CloudFilesStorage(Storage):
     """
-    Custom storage for Mosso Cloud Files.
+    Custom storage for Rackspace Cloud Files.
     """
     default_quick_listdir = True
 
@@ -75,8 +69,7 @@ class CloudFilesStorage(Storage):
 
     def _set_container(self, container):
         """
-        Set the container, making it publicly available (on Limelight CDN) if
-        it is not already.
+        Set the container, making it publicly available if it is not already.
         """
         if not container.is_public():
             container.make_public()
@@ -89,6 +82,8 @@ class CloudFilesStorage(Storage):
     def _get_container_url(self):
         if not hasattr(self, '_container_public_uri'):
             self._container_public_uri = self.container.public_uri()
+        if CNAMES and self._container_public_uri in CNAMES:
+            self._container_public_uri = CNAMES[self._container_public_uri]
         return self._container_public_uri
 
     container_url = property(_get_container_url)
